@@ -342,6 +342,8 @@ class AtlasIndex:
         self.indexed_field = indexed_field
         self.projections = projections
 
+    def _repr_html_(self):
+        return '<br>'.join([d._repr_html_() for d in self.projections])
 
 class AtlasProjection:
     '''
@@ -350,7 +352,8 @@ class AtlasProjection:
     Instead instantiate an AtlasProject and use the project.indices or get_map method to retrieve an AtlasProjection.
     '''
 
-    def __init__(self, project, atlas_index_id: str, projection_id: str, name):
+
+    def __init__(self, project : "AtlasProject", atlas_index_id: str, projection_id: str, name):
         """
         Creates an AtlasProjection.
         """
@@ -367,12 +370,84 @@ class AtlasProjection:
         '''
         return f"{self.project.web_path}/map/{self.project.id}/{self.id}"
 
+    @property
+    def _status(self):
+        response = requests.get(
+            self.project.atlas_api_path + f"/v1/project/index/job/progress/{self.atlas_index_id}",
+            headers=self.project.header,
+        )
+        if response.status_code != 200:
+            raise Exception(response.json()['detail'])
+
+        content = response.json()
+        return content
+
     def __str__(self):
         return f"{self.name}: {self.map_link}"
 
     def __repr__(self):
         return self.__str__()
 
+    def _iframe(self):
+        return f"""
+        <iframe class="iframe" id="iframe{self.id}" allow="clipboard-read; clipboard-write" src="{self.map_link}">
+        </iframe>
+
+        <style>
+            .iframe {{
+                /* vh can be **very** large in vscode ipynb. */
+                height: min(75vh, 66vw);
+                width: 100%;
+            }}
+        </style>
+        """
+    
+    def _embed_html(self):
+        return f"""<script>
+            destroy = function() {{
+                document.getElementById("iframe{self.id}").remove()
+            }}
+        </script>
+
+        <h4>Projection ID: {self.id}</h4>
+        <div class="actions">
+            <div id="hide" class="action" onclick="destroy()">Hide embedded project</div>
+            <div class="action" id="out">
+                <a href="{self.map_link}" target="_blank">Explore on atlas.nomic.ai</a>
+            </div>
+        </div>
+        {self._iframe()}
+        <style>
+            .actions {{
+              display: block;
+            }}
+            .action {{
+              min-height: 18px;
+              margin: 5px;
+              transition: all 500ms ease-in-out;
+            }}
+            .action:hover {{
+              cursor: pointer;
+            }}
+            #hide:hover::after {{
+                content: " X";
+            }}
+            #out:hover::after {{
+                content: "";
+            }}
+        </style>
+        """
+
+    def _repr_html_(self):
+        # Don't make an iframe if the project is locked.
+        state = self._status['index_build_stage']
+        if state != 'Completed':
+            return f"""Atlas Projection {self.name}. Status {state}. <a target="_blank" href="{self.map_link}">view online</a>"""
+        return f"""
+            <h3>Project: {self.name}</h3>
+            {self._embed_html()}
+            """
+    
     def _download_feather(self, dest: str = "tiles"):
         '''
         Downloads the feather tree.
@@ -622,7 +697,6 @@ class AtlasProject(AtlasClass):
         * **project_id** - An alternative way to retrieve a project is by passing the project_id directly. This only works if a project exists.
         * **reset_project_if_exists** - If the specified project exists in your organization, reset it by deleting all of its data. This means your uploaded data will not be contextualized with existing data.
         * **add_datums_if_exists** - If specifying an existing project and you want to add data to it, set this to true.
-        **Returns:** project_id on success.
 
         """
         assert name is not None or project_id is not None, "You must pass a name or project_id"
@@ -828,7 +902,6 @@ class AtlasProject(AtlasClass):
         Returns:
             True if project is unlocked for data additions, false otherwise.
         '''
-        self._latest_project_state()
         return not self.is_locked
 
 
@@ -1044,10 +1117,35 @@ class AtlasProject(AtlasClass):
         m = self.meta
         return f"AtlasProject: <{m}>"
 
+    def _repr_html_(self):
+        self._latest_project_state()
+        m = self.meta
+        html = f"""
+            <strong><a href="https://atlas.nomic.ai/dashboard/project/{m['id']}">{m['project_name']}</strong></a>
+            <br>
+            {m['description']} {m['total_datums_in_project']} datums inserted.
+            <br>
+            {len(m['atlas_indices'])} index built.
+            """
+        complete_projections = []
+        if len(self.projections) >= 1:
+            html += "<br><strong>Projections</strong>\n"
+            html += "<ul>\n"
+            for projection in self.projections:
+                state = projection._status['index_build_stage']
+                if state == 'Completed':
+                    complete_projections.append(projection)
+                html += f"""<li>{projection.name}. Status {state}. <a target="_blank" href="{projection.map_link}">view online</a></li>"""   
+            html += "</ul>"
+        if len(complete_projections) >= 1:
+            # Display most recent complete projection.
+            html += "<hr>"
+            html += complete_projections[-1]._embed_html()
+        return html
+    
     def __str__(self):
         return "\n".join([str(projection) for index in self.indices for projection in index.projections])
 
-
     def get_data(self, ids: List[str]) -> List[Dict]:
         '''
         Retrieve the contents of the data given ids
@@ -1243,8 +1341,6 @@ class AtlasProject(AtlasClass):
             else:
                 logger.info("Text upload succeeded.")
 
-        return True
-
     def add_embeddings(
         self,
         embeddings: np.array,
